This is a copy of the "basic" run from the documentation.

It's used in the test suite to verify that solely Python-defined main input
files, lattices, and profile data can be used (without any custom file formats
or handling HDF5 files directly).
